@@ -1,7 +1,9 @@
 import QUnit from 'qunit'
 import run from './run.js'
+// @ts-ignore
+import * as lib from '#dist/webapi'
 
-run(QUnit, (stats) => {
+run(QUnit, lib, (stats) => {
   // @ts-ignore
   globalThis.stats = stats
 })
